@@ -7,21 +7,22 @@ from pathlib import Path
 
 import piexif
 import pillow_heif
-from loguru import logger
+from loguru import logger as log
 from PIL import Image
 
 from batch_img.common import Common
-from batch_img.const import REPLACE
+from batch_img.const import EXIF, REPLACE
 
-pillow_heif.register_heif_opener()  # allow Pillow to open HEIC files
+pillow_heif.register_heif_opener()
 
 
 class Resize:
     @staticmethod
-    def resize_an_image(in_path: Path, out_path: Path | str, length: int) -> tuple:
+    def resize_an_image(args: tuple) -> tuple:
         """Resize an image file and save to the output dir
 
         Args:
+            args: tuple of the below params:
             in_path: input file path
             out_path: output dir path or REPLACE
             length: max pixels length (width or height)
@@ -29,30 +30,32 @@ class Resize:
         Returns:
             tuple: bool, output file path
         """
+        in_path, out_path, length = args
+        Common.set_log_by_process()
         try:
             with Image.open(in_path) as img:
-                max_size = (length, length)
-                # The thumbnail() keeps the original aspect ratio
-                img.thumbnail(max_size, Image.Resampling.LANCZOS)
-                if out_path == REPLACE:
-                    file = Path(f"{in_path.parent}/{in_path.stem}_tmp{in_path.suffix}")
-                else:
-                    file = Common.set_out_file(in_path, out_path, f"{length}")
+                width, height = img.size
+                new_size = Common.calculate_new_size(width, height, length)
+                new_img = img.resize(new_size, Image.Resampling.LANCZOS, reducing_gap=3)
 
-                if "exif" in img.info:
-                    exif_dict = piexif.load(img.info["exif"])
+                # thumbnail() keep the aspect ratio, but shrink only, not enlarge
+                # img.thumbnail((length, length), Image.Resampling.LANCZOS)
+
+                file = Common.set_out_file(in_path, out_path, f"{length}")
+                if EXIF in img.info:
+                    exif_dict = piexif.load(img.info[EXIF])
                     exif_bytes = piexif.dump(exif_dict)
-                    img.save(file, img.format, optimize=True, exif=exif_bytes)
+                    new_img.save(file, img.format, optimize=True, exif=exif_bytes)
                 else:
-                    img.save(file, img.format, optimize=True)
-            logger.info(f"Saved resized image to {file}")
+                    new_img.save(file, img.format, optimize=True)
+            log.debug(f"Saved resized image to {file}")
             if out_path == REPLACE:
                 os.replace(file, in_path)
-                logger.info(f"Replaced {in_path} with tmp_file")
+                log.debug(f"Replaced {in_path} with the new tmp_file")
                 file = in_path
             return True, file
         except (AttributeError, FileNotFoundError, ValueError) as e:
-            logger.error(e)
+            log.error(e)
             return False, f"{in_path}:\n{e}"
 
     @staticmethod
@@ -70,18 +73,15 @@ class Resize:
             bool: True - Success. False - Error
         """
         image_files = Common.prepare_all_files(in_path, out_path)
-        if not image_files:
-            logger.error(f"No image files at {in_path}")
-            return False
         tasks = [(f, out_path, length) for f in image_files]
         files_cnt = len(tasks)
         if files_cnt == 0:
-            logger.error(f"No image files at {in_path}")
+            log.error(f"No image files at {in_path}")
             return False
 
-        logger.info(f"Resize {files_cnt} image files in multiprocess ...")
+        log.debug(f"Resize {files_cnt} image files in multiprocess ...")
         success_cnt = Common.multiprocess_progress_bar(
-            Resize.resize_an_image, "Resize image files", tasks
+            Resize.resize_an_image, "Resize image files", files_cnt, tasks
         )
-        logger.info(f"\nSuccessfully resized {success_cnt}/{files_cnt} files")
+        log.info(f"\nSuccessfully resized {success_cnt}/{files_cnt} files")
         return True
